function  [sp,f]=frspec(X,N,h,opt_plot);
// Computes the  spectrum of the signal
// Calling Sequence
//	[SP,F]=frspec(X) 
//	[SP,F]=frspec(X,T) 
//	[SP,F]=frspec(X,T,H) 
//	[SP,F]=frspec(...,'plot') 
//   Parameters
//	X : signal (in time) to be analyzed.
//	N : number of frequency bins (default : length(X)).
//	H     : analysis window,   (default : Rect(length(X)). 
//      'plot':	if one input parameter is 'plot', the window will be plotted
//      SP:  spectrum of the signal
//      F  : Normalized frequency vector
//     Examples
//       sig=fmlin(128,0.1,0.4);
//        frspec(sig,'plot');
//    Authors
//      H. Nahrstaedt - Aug 2010	
//

//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA






 [nargout,nargin]=argn(0);
if (nargin == 0),
 error('At least one parameter required');
end;


in_par=['X','N','h','opt_plot'];
in_par_min=1;
plotting=0;
if (nargin>in_par_min)
   if (type(evstr(in_par(nargin)))==10)
     if convstr(evstr(in_par(nargin)))=="plot",   
        plotting=1; 
        clear evstr(in_par(nargin));
        nargin=nargin-1;
     end;
   end;
end;
clear in_par;

[xrow,xcol] = size(X);
time=1:xrow; 


if (nargin == 1),
  N=xrow;h = tftb_window(xrow,'Rect');
elseif (nargin == 2),
   h = tftb_window(xrow,'Rect');
end;

if (xcol==0) | (xcol>1),
 error('X must have one columns');
elseif (2^nextpow2(N)~=N),
 printf('For a faster computation, N should be a power of two\n');
end; 

[hrow,hcol]=size(h); Lh=(hrow-1)/2;
if (hcol~=1)|(hrow~=xrow),
 error('H must have the same length as X');
end;

X=X.*h;

if isreal(X)
 STF = (abs(tftb_fft(fftshift(X),N))); Nstf=length(STF);
 sp = STF(1:Nstf/2); Maxsp=max(sp);
  f = linspace(0,0.5,floor(Nstf/2+1)) ; f=f(1:floor(Nstf/2));
else
 sp = fftshift(abs(tftb_fft(X,N))); 
 Nstf=length(sp);
 Maxsp=max(abs(sp));
  if modulo(Nstf,2)==0
    f=[-Nstf/2+1:-1,0:Nstf/2].'/N;
  else
    f=[-(Nstf-1)/2:-1,0:(Nstf-1)/2].'/N;
  end;
end;
if (plotting)
 plot(f,sp) ; xgrid; 
 xlabel('Normalized frequency');
 title('Analyzed signal spectrum'); 
 a=gca();a.data_bounds=([f(1) f($) 0 1.2*Maxsp]) ; 
end;
endfunction