function [HT,RHO,THETA]=Chtl(IM,M,N)
//	Hough transform for detection of lines in images.
// Calling Sequence
// [HT,RHO,THETA]=Chtl(IM)
// [HT,RHO,THETA]=Chtl(IM,M)
// [HT,RHO,THETA]=Chtl(IM,M,N)
// Parameters
// IM    : image to be analyzed (size Xmax x Ymax).
// M     : desired number of samples along the radial axis   (default : Xmax).
// N     : desired number of samples along the azimutal (angle) axis   (default : Ymax). 
//
// HT    : output matrix (MxN matrix).
// RHO   : sequence of samples along the radial axis.
// THETA : sequence of samples along the azimutal axis.
// Description
// From an image IM, computes the integration of the values
// of the image over all the lines. The lines are parametrized 
// using polar coordinates. The origin of the coordinates is fixed
// at the center of the image, and theta is the angle between the
// VERTICAL axis and the perpendicular (to the line) passing through 
// the origin.
// Examples
//   x = hilbert(sin(2*%pi*0.25*(1:128))+0.5*rand(1,128,'normal'));
//   tfr=Ctfrwv(x); [HT,RHO,THETA]=Chtl(tfr);
//   grayplot(THETA,RHO,HT'); ylabel('rho'); xlabel('theta')
//
// See also
//Ctfrsp
// Authors
// H. Nahrstaedt - Sep 2010
// Emmanuel Roy - 2000
// Manuel Davy - 2000
