function [TFR,T,F]=Ctfrbud(X,T,N,G,H,SIGMA)
// Butterworth time-frequency distribution.
// Calling Sequence
// [TFR,T,F]=Ctfrbud(X)
//[TFR,T,F]=Ctfrbud(X,T)
// [TFR,T,F]=Ctfrbud(X,T,N)
// [TFR,T,F]=Ctfrbud(X,T,N,G) 
//  [TFR,T,F]=Ctfrbud(X,T,N,G,H)
//  [TFR,T,F]=Ctfrbud(X,T,N,G,H,SIGMA)
// Parameters
// X     : Analyzed signal
// T     : time instant(s)          (default : 1:length(X)).
// N     : number of frequency bins (default : length(X)).
// G     : time smoothing window    (default : Hamming(N/4)). 
// H     : frequency smoothing window(default : Hamming(N/4)). 
// SIGMA : kernel width             (default : 1).
// 
// TFR   : time-frequency representation
// F     : vector of normalized frequencies.
//  
// Description
// computes the Butterworth distribution of a signal X.
// Examples
//   x = hilbert(sin(2*%pi*0.25*(1:128))+0.5*rand(1,128,'normal')); 
//   g = Cwindow(9,'Hamming'); h=Cwindow(27,'Hamming'); 
//   t=1:128; [tfr,T,F]=Ctfrbud(x,t,128,g,h,3.6);
//   grayplot(T,F,tfr'); xlabel('time'); ylabel('frequency')
// Authors
// H. Nahrstaedt - Sep 2010
// Emmanuel Roy - 2000
// Manuel Davy - 2000
