function [TFR,T,F]=Ctfrmhs(X,T,N,G,H)
// Margenau-Hill-Spectrogram time-frequency distribution.
// Calling Sequence
// [TFR,T,F]=Ctfrmhs(X)
// [TFR,T,F]=Ctfrmhs(X,T)
// [TFR,T,F]=Ctfrmhs(X,T,N)
// [TFR,T,F]=Ctfrmhs(X,T,N,G)
// [TFR,T,F]=Ctfrmhs(X,T,N,G,H)
// Parameters
// X     : Analyzed signal.
// T     : time instant(s)          (default : 1:length(X)).
// N     : number of frequency bins (default : length(X)).
// G     : time smoothing window,   (default : Hamming(N/10)). 
// H     : frequency smoothing window, in the time-domain,    (default : Hamming(N/4)). 
//
// TFR   : time-frequency representation.
// F     : vector of normalized frequencies.
// Description
// computes the Margenau-Hill-Spectrogram distribution of a  signal X.
// Examples
//   x = hilbert(sin(2*%pi*0.25*(1:128))+0.5*rand(1,128,'normal'));
//   g=Cwindow(21,'Hamming');	 h=Cwindow(63,'Hamming'); 
//   t=1:128; [tfr,T,F]=Ctfrmhs(x,t,128,g,h);
//   grayplot(T,F,tfr');  xlabel('time'); ylabel('frequency')
//
// See also
// Ctfrmh
//Ctfrpmh
//Ctfrsp
// Authors
// H. Nahrstaedt - Sep 2010
// Emmanuel Roy - 2000
// Manuel Davy - 2000