function [TFR,T,F]=Ctfrpmh(X,T,N,H)
// Pseudo Margenau-Hill time-frequency distribution.
// Calling Sequence
// [TFR,T,F]=Ctfrpmh(X)
// [TFR,T,F]=Ctfrpmh(X,T)
// [TFR,T,F]=Ctfrpmh(X,T,N)
// [TFR,T,F]=Ctfrpmh(X,T,N,H)
// Parameters
// X     : Analyzed signal.
// T     : time instant(s)          (default : 1:length(X)).
// N     : number of frequency bins (default : length(X)).
// H     : frequency smoothing window (default : Hamming(N/4)). 
//
// TFR   : time-frequency representation.
// F     : vector of normalized frequencies.
// Description
// computes the Pseudo Margenau-Hill distribution of a  signal X. 
//
// Examples
//   x = hilbert(sin(2*%pi*0.25*(1:128))+0.5*rand(1,128,'normal'));  
//   t=1:128; [tfr,T,F]=Ctfrpmh(x,t,128);
//   grayplot(T,F,tfr');xlabel('time'); ylabel('frequency')
//
// See also
//Ctfrmh
//Ctfrpwv
// Authors
// H. Nahrstaedt - Sep 2010
// Emmanuel Roy - 2000
// Manuel Davy - 2000