function [TFR,T,F]=Ctfrridb(X,T,N,G,H)
//  Reduced Interference Distribution with Bessel kernel.
// Calling Sequence
// [TFR,T,F]=Ctfrridb(X)
//[TFR,T,F]=Ctfrridb(X,T)
// [TFR,T,F]=Ctfrridb(X,T,N)
// [TFR,T,F]=Ctfrridb(X,T,N,G)
// [TFR,T,F]=Ctfrridb(X,T,N,G,H)
// Parameters
// X     : Analyzed signal.
// T     : time instant(s)          (default : 1:length(X)).
// N     : number of frequency bins (default : length(X)).
// G     : time smoothing window,   (default : Hamming(N/10)). 
// H     : frequency smoothing window (default : Hamming(N/4)). 
//
// TFR   : time-frequency representation.
// F     : vector of normalized frequencies.
// Description
// Computes the Reduced Interference Distribution with a kernel
//  based on the Bessel function of the first kind, for a signal X. 
// Examples
//   x = hilbert(sin(2*%pi*0.25*(1:128))+0.5*rand(1,128,'normal'));  
//   g = Cwindow(31,'rect'); h=Cwindow(63,'rect'); 
//   t=1:128; [tfr,T,F]=Ctfrridb(x,t,128,g,h);
//   grayplot(T,F,tfr'); xlabel('time'); ylabel('frequency')
// See also
// Ctfrridh
// Ctfrridt
// Ctfrridbn
// Authors
// H. Nahrstaedt - Sep 2010
// Emmanuel Roy - 2000
// Manuel Davy - 2000




