function [TFR,T,F]=Ctfrspwv(X,T,N,G,H)
//   Smoothed Pseudo Wigner-Ville time-frequency distribution.
// Calling Sequence
// [TFR,T,F]=Ctfrspwv(X)
// [TFR,T,F]=Ctfrspwv(X,T)
// [TFR,T,F]=Ctfrspwv(X,T,N)
// [TFR,T,F]=Ctfrspwv(X,T,N,G)
// [TFR,T,F]=Ctfrspwv(X,T,N,G,H)
// Parameters
// X     : Analyzed signal.
// T     : time instant(s)          (default : 1:length(X)).
// N     : number of frequency bins (default : length(X)).
// G     : time smoothing window,   (default : Hamming(N/10)). 
// H     : frequency smoothing window, in the time-domain,   (default : Hamming(N/4)). 
//
// TFR   : time-frequency representation.
// F     : vector of normalized frequencies.
// Description
// computes the Smoothed Pseudo Wigner-Ville distribution of
// a signal X. 
// Examples
//   x = hilbert(sin(2*%pi*0.25*(1:128))+0.5*rand(1,128,'normal'));  
//   t=1:128; [tfr,T,F]=Ctfrspwv(x,t,128);
//   grayplot(T,F,tfr'); xlabel('time'); ylabel('frequency')
//
// See also
//Ctfrwv
//Ctfrpwv
// Authors
// H. Nahrstaedt - Sep 2010
// Emmanuel Roy - 2000
// Manuel Davy - 2000
