function h=holder(tfr,f,n1,n2,t,pl)
//Estimate the Holder exponent through an affine TFR.
// Calling Sequence
//	H=holder(TFR,F,N1,N2,T) 
// Parameters
//	TFR : affine time-frequency representation.  
//	F   : frequency values of the spectral analysis. 
//	N1  : indice of the  minimum frequency for the linear regression.    (default : 1).
//	N2  : indice of the  maximum frequency for the linear regression.   (default : length(F)).
//	T : time vector. If T is omitted, the function returns the global estimate of the Holder exponent. Otherwise, it  returns the local estimates H(T) at the instants specified  in T.  
//	H : output value (if T omitted) or vector (otherwise) containing   the Holder estimate(s).
// Description
//      holder estimates the Holder exponent of a function through an affine time-frequency representation of it, 
//	and plots the frequency marginal and the regression line.  
// Examples
//       S=altes(128); [TFR,T,F]=tfrscalo(S,1:128,8);
//       H=holder(TFR,F,1,length(F));
//   Authors
//      H. Nahrstaedt - Aug 2010
//	P. Goncalves, October 1995
//	Copyright (c) 1995 Rice University

//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  [nargout,nargin]=argn(0);

tfr = abs(tfr) ;

if nargin<2,
 error('There must be at least 2 input parameters');
elseif nargin==2,
 n1=1; n2=length(f);
elseif nargin==3,
 n2=length(f);
end
if nargin<=5,
 pl=1;
else
 pl=0;
end

if pl, clf; end;

if nargin <= 4
  fmarg = mean(tfr.').' ;
  if pl, plot(log(f),log(fmarg)) ; end;
  p = polyfit(log(f(n1:n2)),log(fmarg(n1:n2)),1) ;
  drt = p(1)*log(f)+p(2) ;
  if pl,
   plot(log(f),drt,'--g') ; 
   legend('Frequency marginal','Regression line');
   plot(log(f([n1 n2])),log(fmarg([n1 n2])),'+r') ;
   xticklabels = round(logspace(log10(min(f)),log10(max(f)),4)*1000)./1000 ;
   //set(gca,'XTick',log(xticklabels)) ; 
   xlabel('frequency (logarithmically spaced)') ;
   //hold off ;
  end
  h = (-p(1)-1)/2 ;
else
  if length(t) == 1
    if pl, plot(log(f),log(tfr(:,t))) ;  end
    p = polyfit(log(f(n1:n2)),log(tfr(n1:n2,t)),1) ;
    drt = p(1)*log(f)+p(2) ;
    if pl, 
     plot(log(f),drt,'--g') ;
     legend('Frequency marginal','Regression line');
     plot(log(f([n1 n2])),log(tfr([n1 n2],t)),'+r') ;
     xticklabels = round(logspace(log10(min(f)),log10(max(f)),4)*1000)./1000 ;
     //set(gca,'XTick',log(xticklabels)) ; 
     xlabel('frequency (logarithmically spaced)') ;
     //hold off ;
    end
    h = (-p(1)-1)/2 ;
  elseif length(t) > 1 
    [yt,xt] = size(t) ; if yt>xt, t = t.' ; end ;
    j = 1 ;
    for k = t,
      p = polyfit(log(f(n1:n2)),log(tfr(n1:n2,k)),1) ;
      h(j) = (-p(1)-1)/2 ; j = j + 1 ;
    end
    if pl, 
     plot(t,h) ;xgrid
     title('Holder estimates at time instants T');
    end
  end,
end
endfunction



function p = polyfit(x, y, n, s)
// return coefficient vector or poly if fourth string argument given
[lhs, rhs] = argn(0)
x = x(:); y = y(:)
m = length(x)
if length(y) <> m, error('x and y must have same length'), end
v = ones(m,n+1)
for i=2:n+1, v(:,i) = x.*v(:,i-1), end
p = (v\y)'
p=p($:-1:1);
if rhs > 3, p = poly(p, s, 'coeff'), end 
endfunction
// 
// function [p, s, mu] = polyfit (x, y, n)
// 
//  [nargout,nargin]=argn(0);
//   if (nargin < 3 | nargin > 4)
//    error("wrong number of parameter!");
//   end
// 
//   if (nargout > 2)
//     // Normalized the x values.
//     mu = [mean(x), mtlb_std(x)];
//     x = (x - mu(1)) / mu(2);
//   end
// 
//   if (~  max(size(x)-size(y))==0)
//     error ("polyfit: x and y must be vectors of the same size");
//   end
// 
//   if (! (isscalar (n) && n >= 0 & ~ isinf (n) & n == round (n)))
//     error ("polyfit: n must be a nonnegative integer");
//   end
// 
//   y_is_row_vector = (rows (y) == 1);
// 
//   // Reshape x & y into column vectors.
//   l = numel (x);
//   x = x(:);
//   y = y(:);
// 
//   // Construct the Vandermonde matrix.
//   v = vander (x, n+1);
// 
//   // Solve by QR decomposition.
//   [q, r, k] = qr (v, 0);
//   p = r \ (q' * y);
//   p(k) = p;
// 
//   if (nargout > 1)
//     yf = v*p;
// 
//     if (y_is_row_vector)
//       s.yf = yf.';
//     else
//       s.yf = yf;
//     end
// 
//     s.R = r;
//     s.X = v;
//     s.df = l - n - 1;
//     s.normr = norm (yf - y);
//   end
// 
//   // Return a row vector.
//   p = p.';
// 
// endfunction
// 
