function [tfr,t,f] = tfrri(x,t,N,ptrace,opt_plot);
//	Rihaczek time-frequency distribution.
// Calling Sequence
//	[TFR,T,F]=tfrri(X) 
//	[TFR,T,F]=tfrri(X,T) 
//	[TFR,T,F]=tfrri(X,T,N) 
//	[TFR,T,F]=tfrri(X,T,N,TRACE) 
//	[TFR,T,F]=tfrri(...,'plot') 
//  Parameters
//	X     : signal if auto-Ri, or [X1,X2] if cross-Ri.
//	T     : time instant(s)           (default : 1:length(X)).
//	N     : number of frequency bins  (default : length(X)).
//	TRACE : if nonzero, the progression of the algorithm is shown     (default : 0).
//      'plot':	if one input parameter is 'plot',  tfrri applies TFRQVIEW on the real     part of the distribution, which is equal to the    Margenau-Hill distribution.
//	TFR   : time-frequency representation.
//	F     : vector of normalized frequencies.
//  Description
//      tfrri computes the Rihaczek distribution
//	of a discrete-time signal X, 
//	or the cross Rihaczek representation between two signals. 
//   Examples
//       sig=fmlin(128,0.1,0.4); tfrri(sig,'plot');
//     Authors
//      H. Nahrstaedt - Aug 2010
//	F. Auger, May-August 1994, July 1995.
//	Copyright (c) 1996 by CNRS (France).

//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 [nargout,nargin]=argn(0);
if (nargin == 0),
 error('At least 1 parameter required');
end;

in_par=['x','t','N','ptrace','opt_plot'];
in_par_min=1;
plotting=0;
if (nargin>in_par_min)
   if (type(evstr(in_par(nargin)))==10)
     if convstr(evstr(in_par(nargin)))=="plot",   plotting=1; end; 
     clear evstr(in_par(nargin));
     nargin=nargin-1;
   end;
end;
clear in_par;


[xrow,xcol] = size(x);
if (nargin == 1),
 t=1:xrow; N=xrow; ptrace=0;
elseif (nargin == 2),
 N=xrow; ptrace=0;
elseif (nargin == 3),
 ptrace = 0;
end;

if (N<0),
 error('N must be greater than zero');
end;
[trow,tcol] = size(t);
if (xcol==0) | (xcol>2),
 error('X must have one or two columns');
elseif (trow~=1),
 error('T must only have one row'); 
elseif (2^nextpow2(N)~=N & nargin==4),
 printf('For a faster computation, N should be a power of two\n');
end; 

tfr= zeros (N,tcol) ;  
if ptrace, disp('Rihaczek distribution'); end;
for icol=1:tcol,
 ti= t(icol); tau=-min([N-ti,xrow-ti]):(ti-1);
 indices= modulo(N+tau,N)+1; 
 if ptrace, disprog(icol,tcol,10); end;
 tfr(indices,icol)=x(ti,1)*conj(x(ti-tau,xcol));
end; 
if ptrace, fprintf('\n'); end;
tfr= tftb_fft(tfr); 

if (plotting),
 printf('if your goal is a graphical output, you should rather use tfrmh.\n');
 tfrqview(real(tfr),x,t,'tfrmh');
end
if (nargout==3),
//  if modulo(N,2)==0, 
//   f=[0:N/2-1 -N/2:-1]'/N;
//  else
//   f=[0:(N-1)/2 -(N-1)/2:-1]'/N;  
//  end;
  f=(0:N-1)/N;
end;
endfunction
