/* interface program between MATLAB and language C
for the program AF2TFR.C */

//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

#include <stdlib.h>
#include <stdio.h>
//#include <stack-c.h>
#include "tftb.h"

//#define AF               prhs[0]
//#define KERNEL           prhs[1]
//#define TFR_OUT          plhs[0]

//#include "divers.c"
//#include "af2tfr.c"

int 
int_Caf2tfr(char *fname)

{
  type_AF        ambif, kernel;
  type_TFR       tfr;
  SciErr sciErr;
  int n,i,nY;
  int retval;
 
  int* piAddressVar     = NULL;
  int iType = 0;  
  int mVar = 0, nVar = 0;
  
  if (!(Rhs == 2)) {
    Scierror(999,"tfr=Caf2tfr(AF,kernel)");
    return 0; 
  }
  CheckRhs (2,2);
  CheckLhs (1,1);
  
  sciErr = getVarAddressFromPosition(pvApiCtx, 1, &piAddressVar);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  } 
    /* check input type */
  sciErr = getVarType(pvApiCtx, piAddressVar, &iType);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  } 

  if (! isVarComplex(pvApiCtx, piAddressVar)){
    Scierror(999,"AF must be complex valued");
    return 0;
  }
  
  sciErr = getComplexMatrixOfDouble(pvApiCtx, piAddressVar, &mVar, &nVar, &ambif.real_part, &ambif.imag_part);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  } 
  
  /* recovery of the AF */
//   ambif.real_part = mxGetPr (AF);
//   ambif.imag_part = mxGetPi (AF);
  ambif.N_doppler = nVar;//mxGetN (AF);
  ambif.N_delay = mVar;//mxGetM (AF);
  ambif.is_complex = TRUE;
  
    sciErr = getVarAddressFromPosition(pvApiCtx, 2, &piAddressVar);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  } 
    /* check input type */
  sciErr = getVarType(pvApiCtx, piAddressVar, &iType);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  } 
    if ( iType != sci_matrix )
  {
    Scierror(999," Kernel must be either empty or a double precision real vector.\n");
    return 0;
  }
  sciErr = getMatrixOfDouble(pvApiCtx, piAddressVar,&mVar,&nVar,&kernel.real_part);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }

  //kernel.real_part = mxGetPr (KERNEL);
  kernel.N_doppler = nVar;//mxGetN (KERNEL);
  kernel.N_delay = mVar;//mxGetM (KERNEL);
  kernel.is_complex = FALSE;

  if ((kernel.N_doppler != ambif.N_doppler) || (kernel.N_delay != ambif.N_delay))
  {
    Scierror(999,"The Ambiguity function and the kernel must be the same size");
    return 0;
  }
  
    if ((kernel.N_doppler != ambif.N_delay) )
  {
    Scierror(999,"The Ambiguity function and the kernel must be quadratic");
    return 0;
  }
  
  tfr.is_complex = FALSE;
  tfr.N_time = ambif.N_doppler;
  tfr.N_freq = ambif.N_delay;
  tfr.real_part =  (double*)malloc(sizeof(double) * tfr.N_time*tfr.N_freq );
   if (tfr.real_part == NULL) {
        Scierror (999,"%s : Memory allocation error.\n",fname); 
        return 0;
    }
  //TFR_OUT = mxCreateDoubleMatrix (tfr.N_freq, tfr.N_time, mxREAL);
   memset(tfr.real_part,0,sizeof(double) * tfr.N_time*tfr.N_freq);
  /* pointer on the results dist */
  //tfr.real_part = mxGetPr (TFR_OUT);
  /* computation of the distance */
  af2tfr (ambif, kernel, tfr);
  sciErr = createMatrixOfDouble(pvApiCtx, Rhs + 1, tfr.N_freq, tfr.N_time, tfr.real_part);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  } 
  
  free(tfr.real_part);
  LhsVar(1) = Rhs + 1; 
    PutLhsVar();
  
  return 0;
}
