/* interface program between Matlab and C language
for AF.C */


//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA


#include <stdlib.h>
#include <stdio.h>
// #include <stack-c.h>
#include "tftb.h"

/* inputs */
#define SIGNAL     1
#define TAU        2
#define N_DOPPLER  3

/* outputs */
// #define AF_OUT     plhs[0]
// #define TAU_OUT    plhs[1]
// #define DOPPL_OUT  plhs[2]

//#include "divers.c"
//#include "af.c"
int 
int_Cambifunb(char *fname)


{
  type_signal    Signal;
  type_AF        AF;
  double        *ptr_delay_vect, *ptr_doppler_vect;
  int            i, rem;
  double         *third;
  int retval;
  
  SciErr sciErr;
  int* piAddressVar     = NULL;
  int iType = 0;  
  int mVar = 0, nVar = 0;

  if ((Rhs < 1) || (Rhs > 3) || (Lhs < 1) || (Lhs > 3)){
    Scierror(999,"[AF,tau,Xi] = Cambifunb(X,TAU,N)");
    return 0;
  }
  CheckRhs (1,3);
  CheckLhs (1,3);

  
  // Signal argument
   sciErr = getVarAddressFromPosition(pvApiCtx, SIGNAL, &piAddressVar);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  } 
    /* check input type */
  sciErr = getVarType(pvApiCtx, piAddressVar, &iType);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  } 
  if ( isVarComplex(pvApiCtx, piAddressVar)){
  sciErr = getComplexMatrixOfDouble(pvApiCtx, piAddressVar, &mVar, &nVar, &Signal.real_part, &Signal.imag_part );
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  } 
  Signal.is_complex = TRUE;
  
  } else {
      sciErr = getMatrixOfDouble(pvApiCtx, piAddressVar, &mVar, &nVar, &Signal.real_part);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  } 
    
    Signal.is_complex = FALSE;
  }
  /* recovery of the signal */
  if (mVar > 1 && nVar > 1){
    Scierror (999,"%s: Wrong size for argument %d: Vector expected.\n", fname, SIGNAL);
    return 0;
  }
  Signal.length = mVar*nVar;
  if (Signal.length == 0){
    Scierror (999,"%s: Wrong size for input argument #%d: Non-empty matrix expected.\n", fname, SIGNAL);
    return 0;
  }
  /* tests whether Signal.length is even or odd */
  rem = ISODD(Signal.length);

  /* recovers data of the signal */
//   Signal.real_part = mxGetPr (SIGNAL);
//   if (mxIsComplex (SIGNAL))
//     {
//       Signal.imag_part = mxGetPi (SIGNAL);
//       Signal.is_complex = TRUE;
//     }
//   else
//     {
//       Signal.is_complex = FALSE;
//     }



  /* recovery of the vector of delay values */
  if (Rhs >= 2)		/* the vector of delays is given */
    {
      sciErr = getVarAddressFromPosition(pvApiCtx, TAU, &piAddressVar);
      if(sciErr.iErr)
      {
	printError(&sciErr, 0);
	return 0;
      } 
      sciErr = getMatrixOfDouble(pvApiCtx, piAddressVar, &mVar, &nVar, &ptr_delay_vect);
      if(sciErr.iErr)
      {
	printError(&sciErr, 0);
	return 0;
      } 
      
      if (mVar > 1 && nVar > 1){
        Scierror (999,"%s: Wrong size for argument %d: Vector expected.\n", fname, TAU);
        return 0;
      }
      AF.N_delay = mVar*nVar;
      if (  AF.N_delay  == 0){
        Scierror (999,"%s: Wrong size for input argument #%d: Non-empty matrix expected.\n", fname, TAU);
        return 0;
      }

    }
  else
    /* the vector of delays is not given */
    {
      AF.N_delay = Signal.length - 1 + rem;
      ptr_delay_vect = NULL;
    }


  /* recovery of the number of doppler bins */
  if (Rhs >= 3)		/* the number of doppler bins is given */
    {
      sciErr = getVarAddressFromPosition(pvApiCtx, N_DOPPLER, &piAddressVar);
      if(sciErr.iErr)
      {
	printError(&sciErr, 0);
	return 0;
      } 
      sciErr = getMatrixOfDouble(pvApiCtx, piAddressVar, &mVar, &nVar, &third);
      if(sciErr.iErr)
      {
	printError(&sciErr, 0);
	return 0;
      } 
       if ( ( (mVar !=1) || (nVar !=1) )&& (mVar>0 && nVar>0))
       {
        Scierror(999,"N must be a positive integer.\n");
	 return 0;
       }
    
      AF.N_doppler = third[0];//mxGetScalar (N_DOPPLER);
    }
  else
    /* the number of doppler bins is not given */
    {
      AF.N_doppler = Signal.length;
    }


  /* the case of the compulsary output : the AF matrix */

  AF.is_complex = TRUE;
  
  //AF_OUT = mxCreateDoubleMatrix (AF.N_doppler, AF.N_delay, mxCOMPLEX);


  /* allocation of memory for the AF matrix according to the pointers required */
  //mem_alloc_AF (&AF, ptr_doppler_vect, ptr_delay_vect, mxGetPr (AF_OUT),mxGetPi (AF_OUT));
  retval=mem_alloc_AF (&AF, NULL, ptr_delay_vect, NULL, NULL);
  if (retval == 4) {
    Scierror (999,"%s : Memory allocation error.\n",fname); 
    return 0;
  }


  /* creation of the vector of delay values in case of no specification */
  if (Rhs < 2)			/* the vector of delays is not given */
    {
      for (i = 0; i < AF.N_delay; i++)
	{
	  AF.delay_bins[i] = -(AF.N_delay - 1.0) / 2.0 + i;
	}
    }
  /* ---------------------------------------------------- */
  /*             calls the computation function           */
  /* ---------------------------------------------------- */
  retval=af (Signal, AF);
  if (retval == 4) {
    Scierror (999,"%s : Memory allocation error.\n",fname); 
    return 0;
  }


   sciErr = createComplexMatrixOfDouble(pvApiCtx, Rhs + 1, AF.N_doppler, AF.N_delay, AF.real_part, AF.imag_part);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  } 
   free(AF.real_part);
   free(AF.imag_part);
   LhsVar(1) = Rhs + 1; 
  
  /* case of the second output */
  if (Lhs >= 2) /* the vector of delay bins is a required output */
    {
//       TAU_OUT = mxCreateDoubleMatrix (1, AF.N_delay, mxREAL);
//       tau_out = mxGetPr (TAU_OUT);
//       for (i = 0; i < AF.N_delay; i++)
// 	{
// 	  tau_out[i] = AF.delay_bins[i];
// 	}
        sciErr = createMatrixOfDouble(pvApiCtx, Rhs + 2, 1, AF.N_delay, AF.delay_bins);
	if(sciErr.iErr)
	{
	  printError(&sciErr, 0);
	  return 0;
	} 
	
	 LhsVar(2) = Rhs + 2; 
    }
    
  /* case of the third output : XI -> vector of doppler values */
  if (Lhs >= 3) /* the vector XI is given */ 
    {
      //DOPPL_OUT = mxCreateDoubleMatrix (1, AF.N_doppler, mxREAL);
      //ptr_doppler_vect = mxGetPr (DOPPL_OUT);
     
         sciErr =  createMatrixOfDouble(pvApiCtx, Rhs + 3, 1, AF.N_doppler, AF.doppler_bins);
	   if(sciErr.iErr)
	  {
	    printError(&sciErr, 0);
	    return 0;
	  } 
	  //free (AF.doppler_bins);
         //free(tfr.real_part);
          LhsVar(3) = Rhs + 3; 
     
     
     
    }
//   else /* the vector XI is not given */
//     {
//       ptr_doppler_vect = NULL;
//     }


  /* ---------------------------------------------------- */
  /*                     Free the memory                  */
  /* ---------------------------------------------------- */
 //  mem_free_AF(&AF);
   if (Rhs < 2)			/* the vector of delays is locally used */
     {
       free (AF.delay_bins);
     }
 
//    if (Lhs < 3)			/* the vector of doppler is locally used */
//      {
       free (AF.doppler_bins);
    // }
     PutLhsVar();
  
  return 0;
}
