/* interface program between MATLAB and kernel.c
SEE kernel.c for comments */


//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

// #include "tftb.h"
// 
// 
// /* input parameters */
#define TFR              1
#define N_THETA          2
#define N_RHO            3
// /* output - result */
// #define HOUGH_OUT        plhs[0]
// #define RHO_OUT          plhs[1]
// #define THETA_OUT        plhs[2]
// 
// 
// 
// 
// 
// #include "divers.c"
// #include "hough.c"
#include <stdlib.h>
#include <stdio.h>
// #include <stack-c.h>
#include "tftb.h"

int 
int_Chtl(char *fname)

{
  int            nb_theta, nb_rho;
  type_TFR       tfr;
  double        *transfo_hough=NULL, *rho_vect=NULL, *theta_vect=NULL;

    SciErr sciErr;
  int* piAddressVar     = NULL;
  int iType = 0;  
  int mVar = 0, nVar = 0;

  /* checks the number of inputs */
  if ((Rhs > 3)||(Rhs<1)||
      (Lhs > 3)||(Lhs<1)){
     Scierror (999,"[HT,RHO,THETA]=Chtl(tfr,nb_theta,nb_rho)");
   return 0;
  }
  CheckRhs (1,3);
  CheckLhs (1,3);

  /* Recovery of the tfr parameter */
     sciErr = getVarAddressFromPosition(pvApiCtx, TFR, &piAddressVar);
    if(sciErr.iErr)
    {
      printError(&sciErr, 0);
      return 0;
    } 
      if ( isVarComplex(pvApiCtx, piAddressVar)){
	Scierror (999,"%s : the input tfr must be real-valued \n",fname);
	return 0;
      }
    
      sciErr = getMatrixOfDouble(pvApiCtx, piAddressVar, &mVar, &nVar, &tfr.real_part);
    if(sciErr.iErr)
    {
      printError(&sciErr, 0);
      return 0;
    } 
    

  tfr.N_freq = nVar;
  tfr.N_time = mVar;
//   tfr.N_freq = mxGetN(TFR);
//   tfr.N_time = mxGetM(TFR);
//   tfr.real_part = mxGetPr(TFR);
  tfr.is_complex = FALSE;

  /* recovery of the other inputs */
  if(Rhs>1)
    {
//       nb_theta = mxGetScalar(N_THETA);
        nb_theta = sciGetUIntScalar(pvApiCtx,N_THETA,  &sciErr);
      if(sciErr.iErr)
      {
	printError(&sciErr, 0);
	return 0;
      }
    }
  else
    {
      nb_theta = tfr.N_time;
    }
 if(Rhs>2)
    {
//       nb_rho = mxGetScalar(N_RHO);
       nb_rho = sciGetUIntScalar(pvApiCtx,N_RHO,  &sciErr);
      if(sciErr.iErr)
      {
	printError(&sciErr, 0);
	return 0;
      }
    }
  else
    {
      nb_rho = tfr.N_freq;
    }

 /* recovery of the outputs */
//  HOUGH_OUT = mxCreateDoubleMatrix(nb_rho,nb_theta,mxREAL);
//  transfo_hough = mxGetPr(HOUGH_OUT);
  transfo_hough = (double*)ALLOC(nb_rho*nb_theta ,sizeof(double) );
      if (transfo_hough == NULL) {
        Scierror (999,"%s : Memory allocation error.\n",fname); 
        return 0;
      }
 /* recovery or creation of the vectors of indices of the matrix */
//  if(Lhs>1) /* rho_vect is required as an output */
//    {
//      RHO_OUT = mxCreateDoubleMatrix(1,nb_rho,mxREAL);
//      rho_vect = mxGetPr(RHO_OUT);
//    }
//  else
//    {
     rho_vect = ALLOC(nb_rho,sizeof(double));
     if (rho_vect == NULL) {
        Scierror (999,"%s : Memory allocation error.\n",fname); 
        return 0;
      }
//    }

//  if(Lhs>2) /* rho_vect is required as an output */
//    {
//      THETA_OUT = mxCreateDoubleMatrix(1,nb_theta,mxREAL);
//      theta_vect = mxGetPr(THETA_OUT);
//    }
//  else
//    {
     theta_vect = ALLOC(nb_theta,sizeof(double));
      if (theta_vect == NULL) {
        Scierror (999,"%s : Memory allocation error.\n",fname); 
        return 0;
      }
//    }

 hough (tfr,nb_theta,nb_rho,transfo_hough,rho_vect,theta_vect);
 
   sciErr = createMatrixOfDouble(pvApiCtx, Rhs + 1, nb_rho, nb_theta, transfo_hough);
   if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  } 
  
  free(transfo_hough);
     LhsVar(1) = Rhs + 1; 
    if (Lhs >= 2)
    {
        sciErr = createMatrixOfDouble(pvApiCtx, Rhs + 2, 1, nb_rho, rho_vect);
         if(sciErr.iErr)
	{
	  printError(&sciErr, 0);
	  return 0;
	} 
       LhsVar(2) = Rhs + 2; 
    }
    if (Lhs >= 3)
    {
      sciErr = createMatrixOfDouble(pvApiCtx, Rhs + 3, 1, nb_theta, theta_vect);
      if(sciErr.iErr)
	{
	  printError(&sciErr, 0);
	  return 0;
	} 
      LhsVar(3) = Rhs + 3; 
    }
  

 /* free the memory */

     free(theta_vect);
     free(rho_vect);

   PutLhsVar();
  
  return 0;
}
