/* interface program between MATLAB and kernel.c
SEE kernel.c for comments */

//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

// #include "tftb.h"
// 
// 
// /* input parameters */
#define N_DOPPLER        1
#define N_DELAY          2
#define KERNEL_NAME      3
#define PARAMETERS       4
// /* output - result */
// #define KERNEL_OUT       plhs[0]

// #include "divers.c"
// #include "af.c"
// #include "kernel.c"
#include <stdlib.h>
#include <stdio.h>
// #include <stack-c.h>
#include "tftb.h"

int 
int_Ctfrker(char *fname)

{
  double        *parameters;
  type_AF        ker;
  int            kernel_name, nb_param, kernel_name_length;
  char          *kernel_name_string;
  
    SciErr sciErr;
  int* piAddressVar     = NULL;
  int iType = 0;  
  int mVar = 0, nVar = 0;

  /* checks the number of inputs */
  if ((Rhs <3)){
    Scierror(999,"ker=Ctfrker(NDoppler,NDelay,kernel_name,parameters)");
    return 0;
  }
  CheckRhs (3,4);
  CheckLhs (1,1);

  /* Recovery of the kernel dimensions */
//   ker.N_delay = mxGetScalar (N_DELAY);
    ker.N_delay = sciGetIntScalar(pvApiCtx,N_DELAY,  &sciErr);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }
//   ker.N_doppler = mxGetScalar (N_DOPPLER);
    ker.N_doppler = sciGetIntScalar(pvApiCtx,N_DOPPLER,  &sciErr);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }
  
  if ((ker.N_delay < 1) || ( ker.N_doppler < 1))
    {
      Scierror(999,"%s : Invalid number of lines / columns in the kernel matrix. \n",fname);
      return 0;
    }
  ker.is_complex = FALSE;

  /* Which kernel shape ? */
//   if(!mxIsChar(KERNEL_NAME))
//     {
//       Scierror(999,"Variable kernel_name must contain a string.\n");
//       return 0;
//     }

//   kernel_name_length = mxGetN(KERNEL_NAME)+1;
//   kernel_name_string = (char *) ALLOC (kernel_name_length,sizeof(char));
//   mxGetString(KERNEL_NAME,kernel_name_string,kernel_name_length);
  
  kernel_name_length = sciGetStringLength(pvApiCtx,KERNEL_NAME, &sciErr);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }
  kernel_name_string = (char *) ALLOC (kernel_name_length,sizeof(char));
  sciGetString(pvApiCtx,KERNEL_NAME, &sciErr, kernel_name_string );
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  }

  /* kernel name recovery */
  kernel_name = 0;
 
  if((!(strcmp(kernel_name_string,"MTEK"))) ||
     (!(strcmp(kernel_name_string,"mtek"))) ||
     (!(strcmp(kernel_name_string,"Mtek"))))
    {
      kernel_name = MTEK;
    }
  if((!(strcmp(kernel_name_string,"GMCWK"))) ||
     (!(strcmp(kernel_name_string,"gmcwk"))) ||
     (!(strcmp(kernel_name_string,"Gmcwk"))))
    {
      kernel_name = GMCWK;
    }
  if((!(strcmp(kernel_name_string,"RGK"))) ||
     (!(strcmp(kernel_name_string,"rgk"))) ||
     (!(strcmp(kernel_name_string,"Rgk"))))
    {
      kernel_name = RGK;
    }
  if((!(strcmp(kernel_name_string,"WV"))) ||
     (!(strcmp(kernel_name_string,"Wv"))) ||
     (!(strcmp(kernel_name_string,"wv"))))
    {
      kernel_name = WIGNER;
    }
  if((!(strcmp(kernel_name_string,"SPECTRO"))) ||
     (!(strcmp(kernel_name_string,"spectro"))) ||
     (!(strcmp(kernel_name_string,"Spectro"))))
    {
      kernel_name = SPECTRO;
    }

  if (kernel_name == 0)
    {
      Scierror(999,"Unknown kernel type");
      free ( kernel_name_string);
      return 0;
    }



  /* recovers the parameters from inputs */
//   parameters = mxGetPr (PARAMETERS);
//   nb_param = (int) MAX (mxGetM (PARAMETERS), mxGetN (PARAMETERS));
if (kernel_name!=WIGNER) {
   sciErr = getVarAddressFromPosition(pvApiCtx, PARAMETERS, &piAddressVar);
    if(sciErr.iErr)
    {
      printError(&sciErr, 0);
      return 0;
    } 
      sciErr = getMatrixOfDouble(pvApiCtx, piAddressVar, &mVar, &nVar, &parameters);
    if(sciErr.iErr)
    {
      printError(&sciErr, 0);
      return 0;
    } 
     nb_param  = (int) MAX (mVar,nVar);

  /* error cases */
  if (kernel_name == MTEK)
    {
      if (nb_param != NB_PARAM_MTEK){
	Scierror(999,"MTEK: 7 parameters are required");
	return 0;
      }
      if (!(((BETA == 1) && (GAMMA == 1)) || ((BETA == 2) && (GAMMA == 0.5)))){
	Scierror(999,"MTEK: beta=gamma=1 or beta=2 and gamma=0.5");
	return 0;
      }
    }
  if (kernel_name == GMCWK)
    {
      if (nb_param < 2){
	Scierror(999,"GMCWK:  at least 2 GMCWK parameters required\n");
	return 0;
      }
    }
  if (kernel_name == RGK)
    {
      if (nb_param < 3){
	Scierror(999,"RGK: at least one pair of Fourier desciptors required");
	return 0;
      }
       if (ISODD(nb_param) == 0)
	  {
	    Scierror (999,"RGK : the number of RGK parameters must be ODD\n");
	    return 0;
	  } 
      
    }
  if (kernel_name == SPECTRO)
    {
      if ((int) (nb_param / 2.0) != (nb_param / 2.0)){
	Scierror(999,"Spectrogramme : the window length must be even");
	return 0;
      }
      if (nb_param > ker.N_delay){
	Scierror(999,"Spectrogramme : the window length must smaller than N_Delay ");
	return 0;
      }
      	if (ISODD(nb_param) == 1)
	  {
	    Scierror (999," the window length must be EVEN for SPECTRO\n");
	    return 0;
	  } 


    }
} else {
  nb_param=0;
  parameters=NULL;
    
}

  /* Creation of the output variable (matrix) */
//   KERNEL_OUT = mxCreateDoubleMatrix (ker.N_doppler, ker.N_delay, mxREAL);

  /* pointer on the results matrix */
//   ker.real_part = mxGetPr (KERNEL_OUT);
  ker.real_part = (double*)malloc(sizeof(double) * ker.N_doppler*ker.N_delay );

  /* computation of the kernel - call to kernel.c */
  kernel (kernel_name, parameters, nb_param, ker);
 sciErr = createMatrixOfDouble(pvApiCtx, Rhs + 1, ker.N_doppler, ker.N_delay, ker.real_part);
   if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  } 
  free(ker.real_part);

  free ( kernel_name_string);
    LhsVar(1) = Rhs + 1; 
    PutLhsVar();
  
  return 0;
}
