//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
/* interface program between MATLAB and language C
  for Reassign.C */

#define SIGNAL            1
#define TIME_INST         2
#define NFFT              3
#define WINDOW           4
// 
// #define TFR_REAS_OUT      plhs[0]
// #define TFR_NOT_REAS_OUT  plhs[1]
// #define FIELD_CPX_OUT     plhs[2]
// 
// #include "tftb.h"
// #include "divers.c"
// #include "create_window.c"
// #include "reassign.c"
// #include "stft.c"
// #include "gradient.c"
// #include "reas_spectro.c"
#include <stdlib.h>
#include <stdio.h>
// #include <stack-c.h>
#include "tftb.h"
int 
int_Ctfrrsp(char *fname)

{
  /*-----------------------------------------------------------------*/
  /*                           VARIABLES                             */
  /*-----------------------------------------------------------------*/
  /* inputs */
  type_signal    Signal;
  int            Window_Length;
  double        *Window=NULL;
  int retval;

  /* outputs */
  type_TFR       TFR_reassigned, TFR_not_reassigned;
  double        *field_time;
  double        *field_freq;

  /* internal */
  int            time;
  double        *ptr_time_inst, *ptr_tfr_not_reas;
  SciErr sciErr;
  int* piAddressVar     = NULL;
  int iType = 0;  
  int mVar = 0, nVar = 0;
  /* some error cases .... */
 
   /* tests the number of inputs and outputs */
  if ((Rhs < 1) || (Rhs > 4) || (Lhs < 1) || (Lhs > 3)){
    Scierror (999,"[TFR_REAS,TFR,FIELD]=Ctfrrsp(signal,[time_instants,Nfft,window])");
    return 0;
  }
        CheckRhs (1,4);
  CheckLhs (1,3);
  
  
  
   sciErr = getVarAddressFromPosition(pvApiCtx, 1, &piAddressVar);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  } 
    /* check input type */
  sciErr = getVarType(pvApiCtx, piAddressVar, &iType);
  if(sciErr.iErr)
  {
    printError(&sciErr, 0);
    return 0;
  } 
  if ( isVarComplex(pvApiCtx, piAddressVar)){
    sciErr = getComplexMatrixOfDouble(pvApiCtx, piAddressVar, &mVar, &nVar, &Signal.real_part, &Signal.imag_part );
    if(sciErr.iErr)
    {
      printError(&sciErr, 0);
      return 0;
    } 
    Signal.is_complex = TRUE;
  
  } else {
      sciErr = getMatrixOfDouble(pvApiCtx, piAddressVar, &mVar, &nVar, &Signal.real_part);
      if(sciErr.iErr)
      {
	printError(&sciErr, 0);
	return 0;
      } 
    
    Signal.is_complex = FALSE;
  }
  /*-----------------------------------------------------------------*/
  /*                      Recovery of the inputs                     */
  /*-----------------------------------------------------------------*/
  /* recovery of the signal */
  if (mVar > 1 && nVar > 1){
    Scierror (999,"%s: Wrong size for argument %d: Vector expected.\n", fname, 1);
    return 0;
  } 
  Signal.length = mVar*nVar;
  if (Signal.length == 0){
    Scierror (999,"%s: Wrong size for input argument #%d: Non-empty matrix expected.\n", fname, 1);
    return 0;
  }
//   Signal.real_part = mxGetPr (SIGNAL);
//   if (mxIsComplex (SIGNAL))
//     {
//       Signal.imag_part = mxGetPi (SIGNAL);
//       Signal.is_complex = TRUE;
//     }
//   else
//     {
//       Signal.is_complex = FALSE;
//     }


  /* case of the structures TFR_reassigned and TFR_not_reassigned */


  /* if there are not the four inputs ... */
  if (Rhs >= 2)			/* the time instants are is given */
    {
      /* TFR dimensions recovery */
//       TFR_reassigned.N_time = (int) MAX (mxGetM (TIME_INST), mxGetN (TIME_INST));
      /* allocation of memory for the 'time_instants' vectors */
//       ptr_time_inst = mxGetPr (TIME_INST);
     sciErr = getVarAddressFromPosition(pvApiCtx, TIME_INST, &piAddressVar);
    if(sciErr.iErr)
    {
      printError(&sciErr, 0);
      return 0;
    } 
      sciErr = getMatrixOfDouble(pvApiCtx, piAddressVar, &mVar, &nVar, &ptr_time_inst);
    if(sciErr.iErr)
    {
      printError(&sciErr, 0);
      return 0;
    } 

      if (mVar > 1 && nVar > 1){
        Scierror (999,"%s: Wrong size for argument %d: Vector expected.\n", fname, 2);
        return 0;
      }
      TFR_reassigned.N_time  = mVar*nVar;
      if ( TFR_reassigned.N_time == 0){
        Scierror (999,"%s: Wrong size for input argument #%d: Non-empty matrix expected.\n", fname, 2);
        return 0;
      }
    }
  else
    /* the time instants are no given */
    {
      /* default : Time_instants = 1:Signal_Length */
      TFR_reassigned.N_time = Signal.length;

      /* allocation of memory for the 'time_instants' vectors */
      ptr_time_inst = NULL;
    }


  if (Rhs >= 3)  /* the Nfft is given */
    {
      //TFR_reassigned.N_freq = (int) mxGetScalar (NFFT);
       TFR_reassigned.N_freq = sciGetUIntScalar(pvApiCtx,NFFT,  &sciErr);
      if(sciErr.iErr)
      {
	printError(&sciErr, 0);
	return 0;
      }
      if (TFR_reassigned.N_freq <= 0 ) {
        Scierror (999, "%s: Wrong argument #%d: Positive integer expected.\n", fname, 3);
        return 0;
      }
    }
  else
    /* the number of frequencies is not given */
    {
      /* default : Nfft = length of the signal */
      TFR_reassigned.N_freq = Signal.length;
    }


  TFR_reassigned.freq_bins = (double *) ALLOC (TFR_reassigned.N_freq, sizeof(double));
  TFR_reassigned.is_complex = FALSE;
  
      if (TFR_reassigned.freq_bins == NULL) {
        Scierror (999,"%s : Memory allocation error.\n",fname); 
        return 0;
      }


  if (Rhs >= 4)     /* the window is given */
    {
      /* recovery of the window and its size */
//       Window = mxGetPr (WINDOW);
//       Window_Length = (int) MAX (mxGetM (WINDOW), mxGetN (WINDOW));
      sciErr = getVarAddressFromPosition(pvApiCtx, WINDOW, &piAddressVar);
    if(sciErr.iErr)
    {
      printError(&sciErr, 0);
      return 0;
    } 
    sciErr = getMatrixOfDouble(pvApiCtx, piAddressVar, &mVar, &nVar, &Window);
    if(sciErr.iErr)
    {
      printError(&sciErr, 0);
      return 0;
    } 
      if (mVar > 1 && nVar > 1){
        Scierror (999,"%s: Wrong size for argument %d: Vector expected.\n", fname, 5);
        return 0;
      } 
      Window_Length = mVar*nVar;
     if (ISODD(Window_Length) == 0) {
        Scierror (999,"%s: Wrong number of input argument(s) : an odd number is expected.\n", fname, 5);
        return 0;
     } 
    }
  else
    {
      /* default : Hamming window of length : the next odd
         number after Signal_Length/4 */
      Window_Length = (int) (TFR_reassigned.N_freq / 4.0);
      if (ISODD(Window_Length) == 0) /* not odd */
	{
	  Window_Length = Window_Length + 1;
	}
      Window = (double *) ALLOC (Window_Length, sizeof (double));
      if (Window == NULL) {
        Scierror (999,"%s : Memory allocation error.\n",fname); 
        return 0;
      }     
      create_window(HAMMING,Window_Length,NULL,0,Window);
    }



  /*-----------------------------------------------------------------*/
  /*                  CHECKS FOR THE OUTPUT VARIABLES                */
  /*-----------------------------------------------------------------*/

  /* Creation of the output variable */
  //TFR_REAS_OUT = mxCreateDoubleMatrix (TFR_reassigned.N_freq,
  //				       TFR_reassigned.N_time, mxREAL);

  /* allocation of memory for TFR_reassigned : the frequency bins */
  /* have to be created - the time instants vector depends on wether */
  /* it is given by the user or not */
  retval=mem_alloc_TFR(&TFR_reassigned,NULL, ptr_time_inst, NULL, NULL);//mxGetPr(TFR_REAS_OUT), NULL);
  if (retval == 4) {
    Scierror (999,"%s : Memory allocation error.\n",fname); 
    return 0;
  }
  
  /* creation of the time_instants vector if not given */
  if (ptr_time_inst == NULL)
    {
      for (time = 0; time < TFR_reassigned.N_time; time++)
	{
	  TFR_reassigned.time_instants[time] = time + 1.0;
	}
    }


  /* case of the non-reassigned tfr */
  TFR_not_reassigned.N_freq = TFR_reassigned.N_freq;
  TFR_not_reassigned.N_time = TFR_reassigned.N_time;
  TFR_not_reassigned.is_complex = FALSE;

 
  /* if more than one output is required */
  //if (Lhs >= 2) /* the unreassigned spectro is passed in the matlab environment */
   // {
      /* creation of the matlab variable */
      //TFR_NOT_REAS_OUT = mxCreateDoubleMatrix (TFR_not_reassigned.N_freq,
	//				       TFR_not_reassigned.N_time, mxREAL);

      /* pointer on the output matrix */
      //ptr_tfr_not_reas = mxGetPr (TFR_NOT_REAS_OUT);
   // }
  //else /* the unreassigned spectro is not required */
  //  {
      ptr_tfr_not_reas = NULL;
  //  }

  /* allocation of memory for TFR_not_reassigned : the frequency bins */
  /* are allready created - the time instants vector too */
  /* it is given by the user or not */
  retval=mem_alloc_TFR(&TFR_not_reassigned,
 		TFR_reassigned.freq_bins, TFR_reassigned.time_instants,
		ptr_tfr_not_reas, NULL);

   if (retval == 4) {
    Scierror (999,"%s : Memory allocation error.\n",fname); 
    return 0;
  }
  //if (Lhs >= 3) /* the field of reassignement is passed in the matlab environment */
    //{
//       /* creation of the matlab variable */
//       FIELD_CPX_OUT = mxCreateDoubleMatrix (TFR_reassigned.N_freq,
// 					    TFR_reassigned.N_time,
// 					    mxCOMPLEX);
// 
//       /* pointer on the output matrices  */
//       field_time = mxGetPr (FIELD_CPX_OUT);
//       field_freq = mxGetPi (FIELD_CPX_OUT);
//       
//     }
//   else
//     /* need to create the variables field_time and field_freq */
//     {
      field_time = 
	(double *) ALLOC (TFR_reassigned.N_time * TFR_reassigned.N_freq,
			  sizeof (double));
      field_freq = 
	(double *) ALLOC (TFR_reassigned.N_time * TFR_reassigned.N_freq,
			  sizeof (double));

//     }
 


  /*-----------------------------------------------------------------*/
  /*                       COMPUTATION                               */
  /*-----------------------------------------------------------------*/
   retval = reas_spectro (Signal,		/*inputs */ 
		Window, Window_Length,  
		TFR_reassigned, TFR_not_reassigned,	/*outputs */ 
		field_time, field_freq); 
   
  if (retval == 6) {
    
    Scierror (999,"%s : Memory allocation error.\n",fname); 
    return 0;
  }
   
      sciErr = createMatrixOfDouble(pvApiCtx, Rhs + 1, TFR_reassigned.N_freq,  TFR_reassigned.N_time, TFR_reassigned.real_part);
      if(sciErr.iErr)
      {
	printError(&sciErr, 0);
	return 0;
      } 
     LhsVar(1) = Rhs + 1; 
     free(TFR_reassigned.real_part);
   
     if (Lhs >= 2)
    {
       sciErr = createMatrixOfDouble(pvApiCtx, Rhs + 2,TFR_not_reassigned.N_freq, TFR_not_reassigned.N_time, TFR_not_reassigned.real_part);
         if(sciErr.iErr)
	{
	  printError(&sciErr, 0);
	  return 0;
	} 
       LhsVar(2) = Rhs + 2; 
    }
      if (Lhs >= 3)
    {
      sciErr = createComplexMatrixOfDouble(pvApiCtx, Rhs + 3, TFR_reassigned.N_freq, TFR_reassigned.N_time, field_time,field_freq);
        if(sciErr.iErr)
      {
	printError(&sciErr, 0);
	return 0;
      } 
      LhsVar(3) = Rhs + 3; 
    }

  /*-----------------------------------------------------------------*/
  /*                         free MEMORY                             */
  /*-----------------------------------------------------------------*/

  if (Rhs < 4)			/* when no window is given */
    {
      free (Window);
    }

  if (Rhs < 2) /* when no time instant vector is given */
    {
      free (TFR_reassigned.time_instants);
    }

 /* the reas. field is not required */
    
      free (field_time); 
      free (field_freq);
    

   /* the unreassigned spectro is not required */
    
      free (TFR_not_reassigned.real_part);
    

   free(TFR_reassigned.freq_bins);
      PutLhsVar();
  
  return 0;
 
}
