mode(-1)
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//function tfrrit
//TFRRIT Unit test for the function TFRRI.

//       O. Lemoine, March 1996.

N=128; 

// Covariance by translation in time 
t1=60; t2=70; f=0.3;
sig1=amgauss(N,t1).*fmconst(N,f,t1); 
sig2=amgauss(N,t2).*fmconst(N,f,t2); 
tfr1=Ctfrri(sig1);  
tfr2=Ctfrri(sig2);        
[tr,tc]=size(tfr1);
tfr=tfr1-tfr2(:,vecmodulo((1:tc)-t1+t2,tc));
if or(or(abs(tfr)>sqrt(%eps))),
 error('tfrri test 1 failed');
end


// Energy conservation
sig=noisecg(N);
tfr=Ctfrri(sig);
Es=norm(sig)^2;
Etfr=sum(mtlb_mean(tfr));
if abs(Es-Etfr)>sqrt(%eps),
 error('tfrri test 2 failed');
end


// Time-marginal
sig=noisecg(N);
tfr=Ctfrri(sig);
ip1=abs(sig).^2;
ip2=mtlb_mean(tfr)';
if or(abs(ip1-ip2)>sqrt(%eps)),
 error('tfrri test 3 failed');
end


// Frequency-marginal
sig=noisecg(N);
tfr=Ctfrri(sig);
FFT=fft(sig);
psd1=abs(FFT(2:N/2)).^2/N;
psd2=real(mtlb_mean(tfr(2:N/2,:)'))';
if or(abs(psd1-psd2)>sqrt(%eps)),
 error('tfrri test 4 failed');
end


// Unitarity
x1=amgauss(N).*fmlin(N);
x2=amexpo2s(N);
tfr1=Ctfrri(x1);
tfr2=Ctfrri(x2);
cor1=abs(x1'*x2)^2;
cor2=real(sum(sum(tfr1.*conj(tfr2)))/N);
if abs(cor1-cor2)>sqrt(%eps),
 error('tfrri test 5 failed');
end


// Conservation of the time support (wide-sense)
sig=[zeros(N/4,1);fmlin(N/2);zeros(N/4,1)];
tfr=Ctfrri(sig);
if sum(or(abs(tfr(:,1:N/4-1))>sqrt(%eps))) | ...
   sum(or(abs(tfr(:,(3*N/4+1):N))>sqrt(%eps))),
 error('tfrri test 6 failed');
end


// time localization
t0=30; sig= ((1:N)'==t0)+0;
tfr=Ctfrri(sig);
[ik,jk]=find(tfr~=0.0);
if or(jk~=t0)|or(ik'-(1:N)'),
 error('tfrri test 7 failed');
end;


N=127; 

// Covariance by translation in time 
t1=61; t2=70; f=0.3;
sig1=amgauss(N,t1).*fmconst(N,f,t1); 
sig2=amgauss(N,t2).*fmconst(N,f,t2); 
tfr1=Ctfrri(sig1);  
tfr2=Ctfrri(sig2);        
[tr,tc]=size(tfr1);
tfr=tfr1-tfr2(:,vecmodulo((1:tc)-t1+t2,tc));
if or(or(abs(tfr)>1e-7)),
 error('tfrri test 8 failed');
end


// Energy conservation
sig=noisecg(N);
tfr=Ctfrri(sig);
Es=norm(sig)^2;
Etfr=sum(mtlb_mean(tfr));
if abs(Es-Etfr)>sqrt(%eps),
 error('tfrri test 9 failed');
end


// Time-marginal
sig=noisecg(N);
tfr=Ctfrri(sig);
ip1=abs(sig).^2;
ip2=mtlb_mean(tfr)';
if or(abs(ip1-ip2)>sqrt(%eps)),
 error('tfrri test 10 failed');
end


// Frequency-marginal
sig=noisecg(N);
tfr=Ctfrri(sig);
FFT=fft(sig);
psd1=abs(FFT(2:fix(N/2))).^2/N;
psd2=real(mtlb_mean(tfr(2:fix(N/2),:)'))';
if or(abs(psd1-psd2)>sqrt(%eps)),
 error('tfrri test 11 failed');
end


// Unitarity
x1=amgauss(N).*fmlin(N);
x2=amexpo2s(N);
tfr1=Ctfrri(x1);
tfr2=Ctfrri(x2);
cor1=abs(x1'*x2)^2;
cor2=real(sum(sum(tfr1.*conj(tfr2)))/N);
if abs(cor1-cor2)>sqrt(%eps),
 error('tfrri test 12 failed');
end


// Conservation of the time support (wide-sense)
sig=[zeros(round(N/4),1);fmlin(round(N/2));zeros(round(N/4),1)];
tfr=Ctfrri(sig);
if sum(or(abs(tfr(:,1:round(N/4)-1))>sqrt(%eps))) | ...
   sum(or(abs(tfr(:,(round(3*N/4)+2):N))>sqrt(%eps))),
 error('tfrri test 13 failed');
end


// time localization
t0=30; sig= ((1:N)'==t0)+0;
tfr=Ctfrri(sig);
[ik,jk]=find(tfr~=0.0);
if or(jk~=t0)|or(ik'-(1:N)'),
 error('tfrri test 14 failed');
end;

