mode(-1)
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//function tfrridnt
//TFRRIDNT Unit test for the function TFRRIDBN.

//       O. Lemoine, June 1996.

// We test each property of the corresponding TFR :

N=128;

// Covariance by translation in time 
t1=55; t2=70; f=0.3;
sig1=amgauss(N,t1).*fmconst(N,f,t1); 
sig2=amgauss(N,t2).*fmconst(N,f,t2); 
tfr1=Ctfrridbn(sig1);  
tfr2=Ctfrridbn(sig2);        
[tr,tc]=size(tfr1);
nu=round(f*(tc-1)*2)+1;
tfr=tfr1-tfr2(:,vecmodulo((1:tc)-t1+t2,tc));
if or(or(abs(tfr)>sqrt(%eps))),
 error('tfrridbn test 1 failed');
end


// Reality of the TFR
sig=noisecg(N);
tfr=Ctfrridbn(sig);
if sum(or(abs(imag(tfr))>sqrt(%eps))),
 error('tfrridbn test 2 failed');
end


// Energy conservation
sig=noisecg(N);
tfr=Ctfrridbn(sig);
Es=norm(sig)^2;
Etfr=sum(mtlb_mean(tfr));
if abs(Es-Etfr)>sqrt(%eps),
 error('tfrridbn test 3 failed');
end


// Time-marginal
sig=noisecg(N);
tfr=Ctfrridbn(sig);
ip1=abs(sig).^2;
ip2=mtlb_mean(tfr)';
if or(abs(ip1-ip2)>sqrt(%eps)),
 error('tfrridbn test 4 failed');
end


// Frequency-marginal
sig=noisecg(N);
tfr=Ctfrridbn(sig,1:N,N,[1],ones(N-1,1));
FFT=fft(sig);
psd1=abs(FFT(2:N/2)).^2/(2*N);
psd2=mtlb_mean(tfr(1:2:N,:)')';
if or(abs(psd1-psd2(2:N/2))>sqrt(%eps)),
 error('tfrridbn test 5 failed');
end


// Conservation of the time support (wide-sense)
sig=[zeros(N/4,1);noisecg(N/2);zeros(N/4,1)];
tfr=Ctfrridbn(sig);
if sum(or(abs(tfr(:,1:N/4-1))>sqrt(%eps))) | ...
   sum(or(abs(tfr(:,(3*N/4+1):N))>sqrt(%eps))),
 error('tfrridbn test 6 failed');
end


// time localization
t0=30; sig=((1:N)'==t0)+0;
tfr=Ctfrridbn(sig);
[ik,jk]=find(tfr~=0.0);
if or(jk~=t0)|or(ik'-(1:N)'),
 error('tfrridbn test 7 failed');
end;


// frequency localization
f0=10;
sig=fmconst(N+6,f0/N);
tfr=Ctfrridbn(sig,N/2+2,N,tftb_window(11,'rect'),tftb_window(N+1,'rect'));
if (find(tfr>1/N)~=2*f0+1)|(abs(mtlb_mean(tfr)-1.0)>3.0*%eps),
 error('tfrridbn test 8 failed');
end;


 N=125;

// Covariance by translation in time 
t1=55; t2=70; f=0.3;
sig1=amgauss(N,t1).*fmconst(N,f,t1); 
sig2=amgauss(N,t2).*fmconst(N,f,t2); 
tfr1=Ctfrridbn(sig1);  
tfr2=Ctfrridbn(sig2);        
[tr,tc]=size(tfr1);
nu=round(f*(tc-1)*2)+1;
tfr=tfr1-tfr2(:,vecmodulo((1:tc)-t1+t2,tc));
if or(or(abs(tfr)>sqrt(%eps))),
 error('tfrridbn test 9 failed');
end


// Reality of the TFR
sig=noisecg(N);
tfr=Ctfrridbn(sig);
if sum(or(abs(imag(tfr))>sqrt(%eps))),
 error('tfrridbn test 10 failed');
end


// Energy conservation
sig=noisecg(N);
tfr=Ctfrridbn(sig);
Es=norm(sig)^2;
Etfr=sum(mtlb_mean(tfr));
if abs(Es-Etfr)>sqrt(%eps),
 error('tfrridbn test 11 failed');
end


// Time-marginal
sig=noisecg(N);
tfr=Ctfrridbn(sig);
ip1=abs(sig).^2;
ip2=mtlb_mean(tfr)';
if or(abs(ip1-ip2)>sqrt(%eps)),
 error('tfrridbn test 12 failed');
end


// Frequency-marginal
sig=noisecg(N);
tfr=Ctfrridbn(sig,1:N,N,[1],ones(N,1));
FFT=mtlb_fft(sig);
psd1=abs(FFT(2:fix(N/2)-3)).^2/(2*N);
psd2=mtlb_mean(tfr(1:2:N,:)')';
if or(abs(psd1-psd2(2:fix(N/2)-3))>5e-1), //5e-2
 error('tfrridbn test 13 failed');
end


// Conservation of the time support (wide-sense)
sig=[zeros(round(N/4),1);noisecg(round(N/2));zeros(round(N/4),1)];
tfr=Ctfrridbn(sig);
if sum(or(abs(tfr(:,1:round(N/4)-1))>sqrt(%eps))) | ...
   sum(or(abs(tfr(:,(round(3*N/4)+2):N))>sqrt(%eps))),
 error('tfrridbn test 14 failed');
end


// time localization
t0=30; sig=((1:N)'==t0)+0;
tfr=Ctfrridbn(sig);
[ik,jk]=find(tfr~=0.0);
if or(jk~=t0)|or(ik'-(1:N)'),
 error('tfrridbn test 15 failed');
end;


// frequency localization
f0=10;
sig=fmconst(N+6,f0/N);
tfr=Ctfrridbn(sig,ceil(N/2)+2,N,tftb_window(11,'rect'),tftb_window(N,'rect'));
if (find(tfr>1/N)~=2*f0+1)|(abs(mtlb_mean(tfr)-1.0)>sqrt(%eps)),
 error('tfrridbn test 16 failed');
end;
