mode(-1)
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//function ffmtt
// 	Unit test for the function ffmt.

//	O. Lemoine - May 1996.

N=128; 

// Perfect reconstruction with iffmt
fmin=0.1; fmax=0.5;
sig=amgauss(N).*fmconst(N,.3); 
[MELLIN,BETA]=ffmt(sig,fmin,fmax,N);
X=iffmt(MELLIN,BETA,N); 
err=abs(X-sig);
if or(err>1e-7),
 error('ffmt test 1 failed');
end


// Energy conservation
x=fmconst(N);
fmin=0.1; fmax=0.4;
FMT=ffmt(x,fmin,fmax,N);
SP=fft(x); 
indmin = 1+round(fmin*(N-2));
indmax = 1+round(fmax*(N-2));
SPana=SP(indmin:indmax);
nu=(indmin:indmax)'/N; 
SPp=SPana./nu;
Es=SPp'*SPana;
Effmt=norm(FMT)^2;
if abs(Es-Effmt)>sqrt(%eps),
 error('ffmt test 2 failed');
end;


// Unitarity of the MT
x1=amgauss(N).*fmlin(N,.15,.35);
x2=amgauss(N).*fmconst(N);
fmin=0.01; fmax=0.49;
FMT1=ffmt(x1,fmin,fmax,2*N);
FMT2=ffmt(x2,fmin,fmax,2*N);
indmin = 1+round(fmin*(2*N-2));
indmax = 1+round(fmax*(2*N-2));
SP1=fft(x1); SP2=fft(x2);
nu=(indmin:indmax)'/N/2; 
SP1p=SP1(indmin:indmax)./nu;
cor1=SP1p'*SP2(indmin:indmax);
cor2=conj(FMT1*FMT2');
if abs(cor1-cor2)>N*1e-2,
 error('ffmt test 3 failed');
end;


// Covariance by dilation 
// Property of the Mellin transform used in scale.
// So as scale works, this property is verified.


// MT of a product = convolution of the MT 
x1=amgauss(N).*fmlin(N,.15,.35);
x2=amgauss(N).*fmsin(N,.15,.35);
FMT1=ffmt(x1,fmin,fmax,2*N);
FMT2=ffmt(x2,fmin,fmax,2*N);
FMT=mtlb_conv(FMT1,FMT2);
FMT=FMT/max(real(FMT));
X1=fft(x1); X2=fft(x2);
X=X1.*X2; 
x=fftshift(ifft(X)); 
FMTp=ffmt(x,fmin,fmax,2*N);
FMTp=FMTp/max(real(FMTp));
Diff=FMTp-FMT(N+1:3*N);		     
if or(abs(Diff)>1e-4),
 error('ffmt test 4 failed');
end



N=121; 

// Perfect reconstruction with iffmt
fmin=0.1; fmax=0.5;
sig=amgauss(N).*fmconst(N,.3); 
[MELLIN,BETA]=ffmt(sig,fmin,fmax,N+1);
X=iffmt(MELLIN,BETA,N); 
err=abs(X-sig);
if or(err>1e-2),
 error('ffmt test 5 failed');
end


// Energy conservation
x=fmconst(N);
fmin=0.1; fmax=0.4;
FMT=ffmt(x,fmin,fmax,N+1);
SP=fft(hilbert(real(x))); 
indmin = 1+round(fmin*(N-2));
indmax = 1+round(fmax*(N-2));
SPana=SP(indmin:indmax);
nu=(indmin:indmax)'/(N+1); 
SPp=SPana./nu;
Es=SPp'*SPana;
Effmt=norm(FMT)^2;
if abs(Es-Effmt)>sqrt(%eps),
 error('ffmt test 6 failed');
end;


// Unitarity of the MT
x1=amgauss(N).*fmlin(N,.15,.35);
x2=amgauss(N).*fmconst(N);
fmin=0.01; fmax=0.49;
FMT1=ffmt(x1,fmin,fmax,2*N);
FMT2=ffmt(x2,fmin,fmax,2*N);
indmin = 1+round(fmin*(2*N-2));
indmax = 1+round(fmax*(2*N-2));
SP1=fft(x1); SP2=fft(x2);
nu=(indmin:indmax)'/N/2; 
SP1p=SP1(indmin:indmax)./nu;
cor1=SP1p'*SP2(indmin:indmax);
cor2=conj(FMT1*FMT2');
if abs(cor1-cor2)>N*1e-2,
 error('ffmt test 7 failed');
end;


// MT of a product = convolution of the MT 
x1=amgauss(N).*fmlin(N,.15,.35);
x2=amgauss(N).*fmsin(N,.15,.35);
FMT1=ffmt(x1,fmin,fmax,2*N);
FMT2=ffmt(x2,fmin,fmax,2*N);
FMT=mtlb_conv(FMT1,FMT2);
FMT=FMT/max(real(FMT));
X1=fft(x1); X2=fft(x2);
X=X1.*X2; 
x=fftshift(ifft(X)); 
FMTp=ffmt(x,fmin,fmax,2*N);
FMTp=FMTp/max(real(FMTp));
Diff=FMTp-FMT(N+1:3*N);		     
if or(abs(Diff)>1e-4),
 error('ffmt test 8 failed');
end

